/*
    innoIndicator - Toolset to control Delcom USB Visual Indicator devices
    
    SetButton
    v1.1
    
    Copyright (c) 2008 Innotronic Ingenieurbüro Markus Meier
    Copyright (c) 2004 Greg Kroah-Hartmanu <greg@kroah.com>
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
    
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.
*/
 
 
#include <stdio.h>
#include <string.h>
#include <usb.h>


#define ButtonPin		0x01
#define ModeBeep		0x80
#define ModeClear		0x40


#define LED_VENDOR_ID	0x0fc5
#define LED_PRODUCT_ID	0x1223



static struct usb_device *device_init(void)
{
	struct usb_bus *usb_bus;
	struct usb_device *dev;
	
	
	usb_init();
	usb_find_busses();
	usb_find_devices();
	
	for( usb_bus = usb_busses; usb_bus; usb_bus = usb_bus->next )
	{
		for( dev = usb_bus->devices; dev; dev = dev->next )
		{
			if(( dev->descriptor.idVendor == LED_VENDOR_ID) &&
			   ( dev->descriptor.idProduct == LED_PRODUCT_ID))
				return dev;
		}
	}
	
	return NULL;
}


int main(int argc, char **argv)
{
	struct usb_device *usb_dev;
	struct usb_dev_handle *usb_handle;
	
	
	usb_dev = device_init();
	
	if( usb_dev == NULL )
	{
		fprintf( stderr, "Device not found\n") ;
		return( -1 );
	}
	
	
	usb_handle = usb_open( usb_dev );
	
	if( usb_handle == NULL )
	{
		fprintf( stderr, "Not able to claim the USB device\n");
		return( -1 );
	}
	
	
	if( argc >= 2 )
	{
		if( strcasecmp( argv[ 1 ], "Off" ) == 0 )
		{
			usb_control_msg( usb_handle,
						 0x0048,
						 0x0012,
						 0x260a,
						 ( ButtonPin << 8 ),
						 NULL,
						 0x0000,
						 1000 );
			
			usb_control_msg( usb_handle,
						 0x0048,
						 0x0012,
						 0x480a,
						 ModeClear | ModeBeep,
						 NULL,
						 0x0000,
						 1000 );
		
		}
		
		if( strcasecmp( argv[ 1 ], "Clear" ) == 0 )
		{
			usb_control_msg( usb_handle,
						 0x0048,
						 0x0012,
						 0x260a,
						 ButtonPin,
						 NULL,
						 0x0000,
						 1000 );
			
			usb_control_msg( usb_handle,
						 0x0048,
						 0x0012,
						 0x480a,
						 ( ModeClear << 8 ) | ModeBeep,
						 NULL,
						 0x0000,
						 1000 );
		
		}
		
		if( strcasecmp( argv[ 1 ], "Beep" ) == 0 )
		{
			usb_control_msg( usb_handle,
						 0x0048,
						 0x0012,
						 0x260a,
						 ButtonPin,
						 NULL,
						 0x0000,
						 1000 );
			
			usb_control_msg( usb_handle,
						 0x0048,
						 0x0012,
						 0x480a,
						 ( ModeBeep << 8 ) | ModeClear,
						 NULL,
						 0x0000,
						 1000 );
		
		}
		
		if( strcasecmp( argv[ 1 ], "ClearBeep" ) == 0 )
		{
			usb_control_msg( usb_handle,
						 0x0048,
						 0x0012,
						 0x260a,
						 ButtonPin,
						 NULL,
						 0x0000,
						 1000 );
			
			usb_control_msg( usb_handle,
						 0x0048,
						 0x0012,
						 0x480a,
						 (( ModeClear | ModeBeep ) << 8 ),
						 NULL,
						 0x0000,
						 1000 );
		
		}
	}
	
	usb_close( usb_handle );

	return( 0 );
}
